
import os
import time

from PyQt4.QtCore import *
from sface.sficonfig import config

def find_executable(exec_name):
    """find the given executable in $PATH"""
    paths = os.getenv("PATH").split(':')
    for p in paths:
        exec_path = os.path.join(p, exec_name)
        if os.path.exists(exec_path):
            return exec_path
    return None


class SfiProcess(QObject):
    def __init__(self, parent=None):
        QObject.__init__(self, parent)

    def __init_command(self, args):
        self.args = QStringList()
        for arg in args:
            self.args << QString(arg)

        self.exe = find_executable("sfi.py")
        self.process = QProcess()

        self.connect(self.process, SIGNAL("finished(int, QProcess::ExitStatus)"),
                     self.processFinished)

    def processFinished(self):
        self.trace_end()
        self.emit(SIGNAL("finished()"))

    def __getRSpec(self, mgr):
        slice = config.getSlice()
        # Write RSpec to file for testing.
        filename = os.path.expanduser("~/.sfi/" + slice + ".rspec")
        try:
            os.remove(filename)
        except:
            pass
        args = ["-u", config.getUser(), "-a", config.getAuthority(), 
                "-r", config.registry(), "-s", mgr, "resources", 
                "-o", filename, slice]

        self.__init_command(args)
        self.start()
        return filename

    def getRSpecFromSM(self):
        return self.__getRSpec(config.slicemgr())

    def getRSpecFromAM(self):
        return self.__getRSpec(config.aggmgr())

    def getRecord(self, hrn):
        args = ["-u", config.getUser(), "-a", config.getAuthority(), 
                "-r", config.registry(), "-s", config.slicemgr(), "show", hrn]
        self.__init_command(args)
        self.start()

    def start(self):
        self.trace_command()
        self.process.start(self.exe, self.args)

    def readOutput(self):
        if self.process.state() == QProcess.NotRunning:
            return self.process.readAll()

    def trace_command (self):
        if config.SFACE_VERBOSE:
            self._trace=time.time()
            command = "%s %s" % (self.exe, self.args.join(" "))
            print time.strftime('%M:%S'),'Invoking',command

    def trace_end (self):
        if config.SFACE_VERBOSE:
            command = "%s %s" % (self.exe, self.args.join(" "))
            print time.strftime('%M:%S'),"[%.3f s]"%(time.time()-self._trace),command,'Done'
